AudioMeterReading class final

Immutable level measurement for one audio frame.

Constructors

AudioMeterReading({required AudioStreamKey stream, required int sequence, required Duration timestamp, required double rms, required double peak, required double decibelsFullScale, required double smoothedRms, required double smoothedPeak, required List<double> rmsByChannel, required List<double> peakByChannel})
Creates a meter reading.

Properties

decibelsFullScale double
Aggregate RMS in dBFS, clamped to the meter floor.
final
hashCode int
The hash code for this object.
no setterinherited
peak double
Aggregate absolute peak amplitude.
final
peakByChannel List<double>
Absolute peak amplitude for each channel.
final
rms double
Aggregate root-mean-square amplitude.
final
rmsByChannel List<double>
Root-mean-square amplitude for each channel.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
Source frame sequence.
final
smoothedPeak double
Attack/release-smoothed aggregate peak.
final
smoothedRms double
Attack/release-smoothed aggregate RMS.
final
stream AudioStreamKey
Stream whose levels were measured.
final
timestamp Duration
Source frame monotonic timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited