WavFileInfo class final
Parsed metadata from a canonical PCM WAV header.
Constructors
Properties
- bitsPerSample → int
-
Stored bits per channel sample.
final
- channels → int
-
Stored channel count.
final
- dataLength → int
-
Audio data length in bytes.
final
- formatCode → int
-
WAVE format code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleFrameCount → int
-
Number of stored interleaved sample frames.
no setter
- sampleRate → int
-
Stored sample frames per second.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited